@@ -38,6 +38,23 @@ def clean_input(func: Callable[..., Any]) -> Callable[..., Any]:
     return wrapper
 
 
+def clean_jitter(value: _T, jitter: int = 1) -> int | _T:
+    """Clean jitter from an integer value.
+
+    If input is int-compatible, remove unwanted jitter
+    `jitter` by lowering value resolution. If any other
+    non-compatible value is given, return it unchanged.
+    """
+
+    vint = safe_int(value)
+    jint = safe_int(jitter, default=1)
+    if isinstance(vint, int) and jint > 0:
+        block_size = 2 * jint + 1
+        return int(vint - (vint % block_size) + jint)
+
+    return value
+
+
 def clean_string(content: str | None) -> str | None:
     """Get a clean string or return None if it is empty."""
 
@@ -265,6 +282,13 @@ def safe_bool(content: str | float | bool | None) -> bool | None:
     return None
 
 
+def safe_bool_nn(content: Any) -> bool:
+    """Read the content as boolean or return False."""
+
+    result = safe_bool(content)
+    return result if isinstance(result, bool) else False
+
+
 def safe_convert(
     convert_func: Callable[[str | int | float], _T],
     content: str | float | None,
@@ -280,11 +304,11 @@ def safe_convert(
         return default
     try:
         return convert_func(content)
-    except ValueError:
+    except (ValueError, TypeError):
         if fallback_func is not None and isinstance(content, str):
             try:
                 return fallback_func(content)
-            except ValueError:
+            except (ValueError, TypeError):
                 pass
         return default
 
@@ -355,6 +379,13 @@ def safe_float(
     return safe_convert(float, content, default)
 
 
+def safe_float_nn(content: Any) -> float:
+    """Read the content as a float or return 0.0."""
+
+    result = safe_float(content)
+    return result if isinstance(result, float) else 0.0
+
+
 @clean_input
 def safe_int(
     content: str | float | None,
